'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*!
 * @author Felix Heck <hi@whoTheHeck.de>
 * @version 0.6.1
 * @copyright Felix Heck 2016
 * @license MIT
 */

var Joi = require('joi');
var Boom = require('boom');
var errors = require('./errors');
var validate = require('./validate');
var header = require('./header');
var pagination = require('./pagination');
var pkg = require('../package.json');

/**
 * @type {Object}
 * @private
 *
 * @description
 * Store internal objects
 */
var internals = {
  defaults: {
    per_page: 100,
    key: 'result'
  },
  scheme: {
    per_page: Joi.number().integer().min(1).max(500).default(100),
    page: Joi.number().integer().min(1).default(1),
    pluginOptions: Joi.object({
      absolute: Joi.boolean().default(false)
    })
  }
};

/**
 * @function
 * @public
 *
 * @description
 * Plugin to generate URIs based on ID and parameters
 *
 * @param {Object} server The server to be extended
 * @param {Object} pluginOptions The plugin options
 * @param {Function} next The callback to continue in the chain of plugins
 */
function bissle(server, pluginOptions, next) {
  pluginOptions = Joi.attempt(pluginOptions, internals.scheme.pluginOptions);

  server.expose('scheme', internals.scheme);
  server.dependency('akaya');

  server.decorate('reply', 'bissle', function decorator(res, options) {
    var _context, _Object$assign;

    options = Object.assign({}, internals.defaults, options);

    if (!validate.options(options)) {
      return this.response(Boom.badRequest(errors.invalidOptions));
    }

    if (!validate.query(this.request.query, options)) {
      return this.response(Boom.badRequest(errors.invalidQuery));
    }

    var _request$query = this.request.query;
    var page = _request$query.page;
    var per_page = _request$query.per_page;

    var offset = (page - 1) * per_page;
    var total = res[options.key].length;
    var result = res[options.key].splice(offset, per_page);
    var id = this.request.route.settings.id;

    if (!id) {
      return this.response(Boom.badRequest(errors.missingId));
    }

    var links = pagination.getLinks(id, page, per_page, total, this.request, (_context = this.request, this.request.aka).bind(_context), options, pluginOptions);

    var linkHeader = header.getLink(links);

    return this.response(Object.assign(res, (_Object$assign = {}, _defineProperty(_Object$assign, options.key, result), _defineProperty(_Object$assign, '_links', links), _defineProperty(_Object$assign, 'per_page', per_page), _defineProperty(_Object$assign, 'page', page), _defineProperty(_Object$assign, 'total', total), _Object$assign))).header('link', linkHeader);
  });

  return next();
}

bissle.attributes = {
  pkg: pkg
};

module.exports = {
  register: bissle
};